package com.vpapps.utils;

import android.app.Activity;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.res.Resources;
import android.graphics.Color;
import android.graphics.Point;
import android.graphics.drawable.GradientDrawable;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.os.Build;
import android.os.Bundle;
import android.util.TypedValue;
import android.view.Display;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import android.widget.LinearLayout;
import android.widget.Toast;

import com.google.ads.consent.ConsentInformation;
import com.google.ads.consent.ConsentStatus;
import com.google.ads.mediation.admob.AdMobAdapter;
import com.google.android.gms.ads.AdListener;
import com.google.android.gms.ads.AdRequest;
import com.google.android.gms.ads.AdSize;
import com.google.android.gms.ads.AdView;
import com.google.android.gms.ads.InterstitialAd;
import com.google.android.material.snackbar.Snackbar;
import com.google.gson.Gson;
import com.google.gson.JsonObject;
import com.vpapps.hdwallpaper.BuildConfig;
import com.vpapps.hdwallpaper.LoginActivity;
import com.vpapps.hdwallpaper.R;
import com.vpapps.interfaces.InterAdListener;
import com.vpapps.items.ItemUser;
import com.yakivmospan.scytale.Crypto;
import com.yakivmospan.scytale.Options;
import com.yakivmospan.scytale.Store;

import java.text.DecimalFormat;

import javax.crypto.SecretKey;

import androidx.appcompat.app.AlertDialog;
import okhttp3.MultipartBody;
import okhttp3.RequestBody;

public class Methods {

    private Context context;
    private InterAdListener interAdListener;
    private SecretKey key;

    // constructor
    public Methods(Context context) {
        this.context = context;

        Store store = new Store(context);
        if (!store.hasKey(BuildConfig.ENC_KEY)) {
            key = store.generateSymmetricKey(BuildConfig.ENC_KEY, null);
        } else {
            key = store.getSymmetricKey(BuildConfig.ENC_KEY, null);
        }
    }

    // constructor
    public Methods(Context context, InterAdListener interAdListener) {
        this.context = context;
        this.interAdListener = interAdListener;

        Store store = new Store(context);
        if (!store.hasKey(BuildConfig.ENC_KEY)) {
            key = store.generateSymmetricKey(BuildConfig.ENC_KEY, null);
        } else {
            key = store.getSymmetricKey(BuildConfig.ENC_KEY, null);
        }
    }

    public boolean isNetworkAvailable() {
        ConnectivityManager connectivityManager
                = (ConnectivityManager) context.getSystemService(Context.CONNECTIVITY_SERVICE);
        NetworkInfo activeNetworkInfo = connectivityManager.getActiveNetworkInfo();
        return activeNetworkInfo != null && activeNetworkInfo.isConnected();
    }

    public int getScreenWidth() {
        int columnWidth;
        WindowManager wm = (WindowManager) context
                .getSystemService(Context.WINDOW_SERVICE);
        Display display = wm.getDefaultDisplay();

        final Point point = new Point();

        point.x = display.getWidth();
        point.y = display.getHeight();

        columnWidth = point.x;
        return columnWidth;
    }

    public int getScreenHeight() {
        WindowManager wm = (WindowManager) context
                .getSystemService(Context.WINDOW_SERVICE);
        Display display = wm.getDefaultDisplay();

        final Point point = new Point();
        point.y = display.getHeight();

        return point.y;
    }

    public void forceRTLIfSupported(Window window) {
        if (context.getResources().getString(R.string.isRTL).equals("true")) {
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.JELLY_BEAN_MR1) {
                window.getDecorView().setLayoutDirection(View.LAYOUT_DIRECTION_RTL);
            }
        }
    }

    public void clickLogin() {
        if (Constant.isLogged) {
            logout((Activity) context);
            Toast.makeText(context, context.getString(R.string.logout_success), Toast.LENGTH_SHORT).show();
        } else {
            Intent intent = new Intent(context, LoginActivity.class);
            intent.putExtra("from", "app");
            context.startActivity(intent);
        }
    }

    private void changeAutoLogin(Boolean isAutoLogin) {
        SharedPref sharePref = new SharedPref(context);
        sharePref.setIsAutoLogin(isAutoLogin);
    }

    public void logout(Activity activity) {
        changeAutoLogin(false);
        Constant.isLogged = false;
        Constant.itemUser = new ItemUser("", "", "", "");
        Intent intent1 = new Intent(context, LoginActivity.class);
        intent1.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK | Intent.FLAG_ACTIVITY_CLEAR_TASK);
        intent1.putExtra("from", "");
        context.startActivity(intent1);
        activity.finish();
    }

    public void showInter(final int pos, final String type) {
        if (Constant.isInterAd) {
            Constant.adCount = Constant.adCount + 1;
            if (Constant.adCount % Constant.adShow == 0) {
                final InterstitialAd interstitialAd = new InterstitialAd(context);
                AdRequest adRequest;
                if (ConsentInformation.getInstance(context).getConsentStatus() == ConsentStatus.PERSONALIZED) {
                    adRequest = new AdRequest.Builder()
                            .build();
                } else {
                    Bundle extras = new Bundle();
                    extras.putString("npa", "1");
                    adRequest = new AdRequest.Builder()
                            .addNetworkExtrasBundle(AdMobAdapter.class, extras)
                            .build();
                }
                interstitialAd.setAdUnitId(Constant.ad_inter_id);
                interstitialAd.loadAd(adRequest);
                interstitialAd.setAdListener(new AdListener() {
                    @Override
                    public void onAdLoaded() {
                        super.onAdLoaded();
                        interstitialAd.show();
                    }

                    public void onAdClosed() {
                        interAdListener.onClick(pos, type);
                        super.onAdClosed();
                    }

                    @Override
                    public void onAdFailedToLoad(int i) {
                        interAdListener.onClick(pos, type);
                        super.onAdFailedToLoad(i);
                    }
                });
            } else {
                interAdListener.onClick(pos, type);
            }
        } else {
            interAdListener.onClick(pos, type);
        }
    }

    private void showPersonalizedAds(LinearLayout linearLayout) {
        if (Constant.isBannerAd) {
            AdView adView = new AdView(context);
            AdRequest adRequest = new AdRequest.Builder().addTestDevice("0336997DCA346E1612B610471A578EEB").build();
            adView.setAdUnitId(Constant.ad_banner_id);
            adView.setAdSize(AdSize.BANNER);
            linearLayout.addView(adView);
            adView.loadAd(adRequest);
        }
    }

    private void showNonPersonalizedAds(LinearLayout linearLayout) {
        Bundle extras = new Bundle();
        extras.putString("npa", "1");
        if (Constant.isBannerAd) {
            AdView adView = new AdView(context);
            AdRequest adRequest = new AdRequest.Builder()
                    .addNetworkExtrasBundle(AdMobAdapter.class, extras)
                    .build();
            adView.setAdUnitId(Constant.ad_banner_id);
            adView.setAdSize(AdSize.BANNER);
            linearLayout.addView(adView);
            adView.loadAd(adRequest);
        }
    }

    public void showBannerAd(LinearLayout linearLayout) {
        if (isNetworkAvailable() && linearLayout != null) {
            if (ConsentInformation.getInstance(context).getConsentStatus() == ConsentStatus.NON_PERSONALIZED) {
                showNonPersonalizedAds(linearLayout);
            } else {
                showPersonalizedAds(linearLayout);
            }
        }
    }

    public void showSnackBar(View linearLayout, String message) {
        Snackbar snackbar = Snackbar.make(linearLayout, message, Snackbar.LENGTH_SHORT);
        snackbar.getView().setBackgroundResource(R.drawable.bg_grt_toolbar);
        snackbar.show();
    }

    public void setStatusColor(Window window) {
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) {
            window.getDecorView().setSystemUiVisibility(
                    View.SYSTEM_UI_FLAG_LAYOUT_STABLE
                            | View.SYSTEM_UI_FLAG_LAYOUT_FULLSCREEN);
            window.setStatusBarColor(Color.TRANSPARENT);
        }
    }

    public GradientDrawable getRoundDrawable(int color) {
        GradientDrawable gd = new GradientDrawable();
        gd.setColor(color);
        gd.mutate();
        gd.setCornerRadius(10);
        return gd;
    }

    public GradientDrawable getRoundDrawableRadis(int color, int radius) {
        GradientDrawable gd = new GradientDrawable();
        gd.setColor(color);
        gd.mutate();
        gd.setCornerRadius(radius);
        return gd;
    }

    public String format(Number number) {
        char[] suffix = {' ', 'k', 'M', 'B', 'T', 'P', 'E'};
        long numValue = number.longValue();
        int value = (int) Math.floor(Math.log10(numValue));
        int base = value / 3;
        if (value >= 3 && base < suffix.length) {
            return new DecimalFormat("#0.0").format(numValue / Math.pow(10, base * 3)) + suffix[base];
        } else {
            return new DecimalFormat("#,##0").format(numValue);
        }
    }

    public void getVerifyDialog(String title, String message) {
        final AlertDialog.Builder alertDialog = new AlertDialog.Builder(context, R.style.ThemeDialog);
        alertDialog.setTitle(title);
        alertDialog.setMessage(message);
        alertDialog.setCancelable(false);

        alertDialog.setPositiveButton(context.getString(R.string.ok), new DialogInterface.OnClickListener() {
            @Override
            public void onClick(DialogInterface dialog, int which) {
//                finish();
            }
        });
        alertDialog.show();
    }

    public String getImageThumbSize(String imagePath, String type) {
        if (type.equals(context.getString(R.string.portrait)) || type.equals("")) {
            imagePath = imagePath.replace("&size=300x300", "&size=200x350");
        } else if (type.equals(context.getString(R.string.landscape))) {
            imagePath = imagePath.replace("&size=300x300", "&size=350x200");
        } else if (type.equals(context.getString(R.string.square))) {
            imagePath = imagePath.replace("&size=300x300", "&size=300x300");
        } else if (type.equals(context.getString(R.string.details))) {
            imagePath = imagePath.replace("&size=300x300", "&size=500x500");
        } else if (type.equals(context.getString(R.string.home).concat(Constant.TAG_PORTRAIT))) {
            imagePath = imagePath.replace("&size=300x300", "&size=400x550");
        } else if (type.equals(context.getString(R.string.home).concat(Constant.TAG_LANDSCAPE))) {
            imagePath = imagePath.replace("&size=300x300", "&size=550x400");
        } else if (type.equals(context.getString(R.string.home).concat(Constant.TAG_SQUARE))) {
            imagePath = imagePath.replace("&size=300x300", "&size=500x500");
        } else if (type.equals(context.getString(R.string.categories))) {
            imagePath = imagePath.replace("&size=300x300", "&size=300x250");
        }
        return imagePath;
    }

    public int getColumnWidth(int column, int grid_padding) {
        Resources r = context.getResources();
        float padding = TypedValue.applyDimension(TypedValue.COMPLEX_UNIT_DIP, grid_padding, r.getDisplayMetrics());
        return (int) ((getScreenWidth() - ((column + 1) * padding)) / column);
    }

    public String encrypt(String value) {
        try {
            Crypto crypto = new Crypto(Options.TRANSFORMATION_SYMMETRIC);
            return crypto.encrypt(value, key);
        } catch (Exception e) {
            Crypto crypto = new Crypto(Options.TRANSFORMATION_SYMMETRIC);
            return crypto.encrypt("null", key);
        }
    }

    public String decrypt(String value) {
        try {
            Crypto crypto = new Crypto(Options.TRANSFORMATION_SYMMETRIC);
            return crypto.decrypt(value, key);
        } catch (Exception e) {
            e.printStackTrace();
            return "null";
        }
    }

    public RequestBody getAPIRequest(String method, int page, String deviceID, String wallType, String cat_id, String searchText, String itemID, String rate, String name, String email, String password, String phone, String userID, String reportFor) {
        JsonObject jsObj = (JsonObject) new Gson().toJsonTree(new API());
        jsObj.addProperty("method_name", method);
        jsObj.addProperty("package_name", context.getPackageName());

        switch (method) {
            case Constant.METHOD_HOME:
                jsObj.addProperty("type", wallType);
                break;
            case Constant.METHOD_CAT:
                jsObj.addProperty("type", wallType);
                break;

            case Constant.METHOD_LATEST_WALL:
                jsObj.addProperty("page", String.valueOf(page));
                jsObj.addProperty("type", wallType);
                jsObj.addProperty("color_id", userID);
                break;

            case Constant.METHOD_LATEST_GIF:
                jsObj.addProperty("page", String.valueOf(page));
                break;

            case Constant.METHOD_MOST_VIEWED:
                jsObj.addProperty("page", String.valueOf(page));
                jsObj.addProperty("type", wallType);
                jsObj.addProperty("color_id", userID);
                break;

            case Constant.METHOD_MOST_VIEWED_GIF:
                jsObj.addProperty("page", String.valueOf(page));
                break;

            case Constant.METHOD_MOST_RATED_GIF:
                jsObj.addProperty("page", String.valueOf(page));
                break;

            case Constant.METHOD_MOST_RATED:
                jsObj.addProperty("page", String.valueOf(page));
                jsObj.addProperty("type", wallType);
                jsObj.addProperty("color_id", userID);
                break;

            case Constant.METHOD_WALLPAPER_BY_CAT:
                jsObj.addProperty("page", String.valueOf(page));
                jsObj.addProperty("type", wallType);
                jsObj.addProperty("cat_id", cat_id);
                jsObj.addProperty("color_id", userID);
                break;

            case Constant.METHOD_WALL_SEARCH:
                jsObj.addProperty("search_text", searchText);
                jsObj.addProperty("type", wallType);
                jsObj.addProperty("color_id", userID);
                break;

            case Constant.METHOD_GIF_SEARCH:
                jsObj.addProperty("gif_search_text", searchText);
                break;

            case Constant.METHOD_WALL_DOWNLOAD:
                jsObj.addProperty("wallpaper_id", itemID);
                break;

            case Constant.METHOD_GIF_DOWNLOAD:
                jsObj.addProperty("gif_id", itemID);
                break;

            case Constant.METHOD_WALL_SINGLE:
                jsObj.addProperty("wallpaper_id", itemID);
                break;

            case Constant.METHOD_GIF_SINGLE:
                jsObj.addProperty("gif_id", itemID);
                break;

            case Constant.METHOD_WALL_RATING:
                jsObj.addProperty("post_id", itemID);
                jsObj.addProperty("device_id", deviceID);
                jsObj.addProperty("rate", rate);
                break;

            case Constant.METHOD_GIF_RATING:
                jsObj.addProperty("post_id", itemID);
                jsObj.addProperty("device_id", deviceID);
                jsObj.addProperty("rate", rate);
                break;

            case Constant.METHOD_WALL_GET_RATING:
                jsObj.addProperty("post_id", itemID);
                jsObj.addProperty("device_id", deviceID);
                break;

            case Constant.METHOD_GIF_GET_RATING:
                jsObj.addProperty("post_id", itemID);
                jsObj.addProperty("device_id", deviceID);
                break;

            case Constant.METHOD_LOGIN:
                jsObj.addProperty("email", email);
                jsObj.addProperty("password", password);
                break;

            case Constant.METHOD_REGISTRATION:
                jsObj.addProperty("name", name);
                jsObj.addProperty("email", email);
                jsObj.addProperty("password", password);
                jsObj.addProperty("phone", phone);
                break;

            case Constant.METHOD_FORGOT_PASSWORD:
                jsObj.addProperty("email", email);
                break;

            case Constant.METHOD_PROFILE:
                jsObj.addProperty("user_id", userID);
                break;

            case Constant.METHOD_EDIT_PROFILE:
                jsObj.addProperty("user_id", userID);
                jsObj.addProperty("name", name);
                jsObj.addProperty("email", email);
                jsObj.addProperty("password", password);
                jsObj.addProperty("phone", phone);
                break;

            case Constant.METHOD_REPORT:
                jsObj.addProperty("user_id", userID);
                jsObj.addProperty("item_id", itemID);
                jsObj.addProperty("user_txt", searchText);
                jsObj.addProperty("report_for", reportFor);
                break;
        }

//        Log.e("aaa", API.toBase64(jsObj.toString()));
        return new MultipartBody.Builder()
                .setType(MultipartBody.FORM)
                .addFormDataPart("data", API.toBase64(jsObj.toString()))
                .build();
    }
}